@@ -1,11 +1,13 @@
 package App::JobLog::Log::Event;
 {
-  $App::JobLog::Log::Event::VERSION = '1.022';
+  $App::JobLog::Log::Event::VERSION = '1.023';
 }
 
 # ABSTRACT: basically adds an end time to App::JobLog::Log::Line events
 
 
+use parent qw(App::JobLog::Log::Note);
+
 use Modern::Perl;
 use Class::Autouse qw{DateTime};
 use autouse 'App::JobLog::Time' => qw(now);
@@ -16,15 +18,6 @@ use overload '""' => sub {
     $_[0]->data->to_string . '-->'
       . ( $_[0]->is_closed ? $_[0]->end : 'ongoing' );
 };
-use overload 'bool' => sub { 1 };
-
-
-sub new {
-    my ( $class, $logline ) = @_;
-    $class = ref $class || $class;
-    my $self = bless { log => $logline }, $class;
-    return $self;
-}
 
 
 sub clone {
@@ -54,62 +47,31 @@ sub overlap {
 }
 
 
-sub data {
-    $_[0]->{log};
-}
-
-
-sub start : lvalue {
-    $_[0]->data->time;
-}
-
-
 sub end : lvalue {
     $_[0]->{end};
 }
 
 
-sub tags : lvalue {
-    $_[0]->data->{tags};
-}
-
-
-sub exists_tag {
-    my ( $self, @tags ) = @_;
-    $self->data->exists_tag(@tags);
-}
-
-
-sub all_tags {
-    my ( $self, @tags ) = @_;
-    $self->data->all_tags(@tags);
-}
-
-
 sub cmp {
     my ( $self, $other ) = @_;
-    carp 'argument must also be event' unless $other->isa(__PACKAGE__);
-
-    # defer to subclass sort order if other is a subclass and self isn't
-    return -$other->cmp($self)
-      if ref $self eq __PACKAGE__ && ref $other ne __PACKAGE__;
-
-    my $comparison = DateTime->compare( $self->start, $other->start );
+    my $comparison = $self->SUPER::cmp($other);
     unless ($comparison) {
-        if ( $self->is_closed ) {
-            if ( $other->is_closed ) {
-                return DateTime->compare( $self->end, $other->end );
+        if ( $other->isa(__PACKAGE__) ) {
+            if ( $self->is_closed ) {
+                if ( $other->is_closed ) {
+                    return DateTime->compare( $self->end, $other->end );
+                }
+                else {
+                    return 1;
+                }
+            }
+            elsif ( $other->is_closed ) {
+                return -1;
             }
             else {
-                return 1;
+                return 0;
             }
         }
-        elsif ( $other->is_closed ) {
-            return -1;
-        }
-        else {
-            return 0;
-        }
     }
     return $comparison;
 }
@@ -132,7 +94,8 @@ sub split_days {
     my ($self) = @_;
     my $days_end =
       $self->start->clone->truncate( to => 'day' )->add( days => 1 );
-    if ( $days_end < ( $self->end || now ) ) {
+    my $e = $self->end || now;
+    if ( $days_end < $e ) {
         my @splits;
         my $s = $self->start;
         do {
@@ -142,7 +105,7 @@ sub split_days {
             $clone->end   = $s;
             push @splits, $clone;
             $days_end->add( days => 1 );
-        } while ( $days_end < $self->end );
+        } while ( $days_end < $e );
         my $clone = $self->clone;
         $clone->start = $s;
         $clone->end   = $self->end;
@@ -154,15 +117,6 @@ sub split_days {
     }
 }
 
-# unrolls a calendrical interval onto a timeline
-sub _interval {
-    my ( $self, $unit ) = @_;
-    my $d2 =
-      $self->end->subtract_datetime( $self->start )->in_units( $unit . 's' );
-    my $d1 = $self->start->$unit;
-    return $d1, $d1 + $d2;
-}
-
 
 sub intersects {
     my ( $self, $other ) = @_;
@@ -187,7 +141,7 @@ App::JobLog::Log::Event - basically adds an end time to App::JobLog::Log::Line e
 
 =head1 VERSION
 
-version 1.022
+version 1.023
 
 =head1 DESCRIPTION
 
@@ -198,11 +152,6 @@ handle the properties of intervals of time as distinct from points.
 
 =head1 METHODS
 
-=head2 new
-
-Basic constructor. Expects single L<App::JobLog::Log::Line> argument. Can be called on
-instance or class.
-
 =head2 clone
 
 Create a duplicate of this event.
@@ -212,30 +161,10 @@ Create a duplicate of this event.
 Expects two L<DateTime> objects as arguments. Returns the portion of this event
 overlapping the interval so defined.
 
-=head2 data
-
-Returns L<App::JobLog::Log::Line> object on which this event is based.
-
-=head2 start
-
-Start of event. Is lvalue method.
-
 =head2 end
 
 End of event. Is lvalue method.
 
-=head2 tags
-
-Tags of event (array reference). Is lvalue method.
-
-=head2 exists_tag
-
-Expects a list of tags. Returns true if event contains any of them.
-
-=head2 all_tags
-
-Expects a list of tags. Returns whether event contains all of them.
-
 =head2 cmp
 
 Used to sort events. E.g.,
